@@ -9,6 +9,7 @@ from . import (
     constants,
     context,
     exceptions,
+    handlers,
     highlight,
     interpreter,
     lexer,
@@ -34,6 +35,7 @@ __all__ = [
     'constants',
     'context',
     'exceptions',
+    'handlers',
     'highlight',
     'interpreter',
     'lexer',
